"use strict";
/**
 * Created by jackyanjiaqi on 16/7/19.
 */
const child_process_1 = require("child_process");
const path = require("path");
function open(target, appName, callback, options) {
    var opener;
    if (typeof (appName) === 'function') {
        callback = appName;
        appName = null;
    }
    switch (process.platform) {
        case 'darwin':
            if (appName) {
                opener = 'open -a "' + escape(appName) + '"';
            }
            else {
                opener = 'open';
            }
            break;
        case 'win32':
            // if the first parameter to start is quoted, it uses that as the title
            // so we pass a blank title so we can quote the file we are opening
            if (appName) {
                opener = 'start "" "' + escape(appName) + '"';
            }
            else {
                opener = 'start ""';
            }
            break;
        default:
            if (appName) {
                opener = escape(appName);
            }
            else {
                // use Portlands xdg-open everywhere else
                opener = path.join(__dirname, '../vendor/xdg-open');
            }
            break;
    }
    return child_process_1.exec(opener + ' "' + escape(target) + '"', options, callback);
}
exports.open = open;
function escape(s) {
    return s.replace(/"/, '\\\"');
}
function isEmptyObject(e) {
    for (let t in e) {
        return !1;
    }
    return !0;
}
exports.isEmptyObject = isEmptyObject;
(function (Direction) {
    Direction[Direction["FRONT"] = 0] = "FRONT";
    Direction[Direction["END"] = 1] = "END";
})(exports.Direction || (exports.Direction = {}));
var Direction = exports.Direction;
/**
 * URL处理器
 */
class URLHandler {
    constructor() {
        this.start = -1;
        this.end = -1;
        this.raw = null;
        this.data = null;
    }
    static getInstance() {
        if (!this.__singleton) {
            this.__singleton = new URLHandler();
        }
        return this.__singleton;
    }
    filter(markBegin, markEnd, mixedStr) {
        if (mixedStr) {
            this.raw = mixedStr;
        }
        this.start = this.raw.indexOf(markBegin);
        this.end = this.raw.indexOf(markEnd) + markEnd.length;
        this.data = this.raw.substring(this.start, this.end);
        return this;
    }
    add(d, word) {
        let startBefore = this.raw.substring(0, this.start);
        let endAfter = this.raw.substring(this.end);
        let filteredURL = this.data;
        switch (d) {
            case Direction.FRONT:
                this.data = `${startBefore}${word}${filteredURL}${endAfter}`;
                break;
            case Direction.END:
                this.data = `${startBefore}${filteredURL}${word}${endAfter}`;
                break;
        }
        return this;
    }
    new(raw) {
        if (raw) {
            this.raw = raw;
        }
        else {
            this.raw = this.data;
        }
        this.data = null;
        this.start = -1;
        this.end = -1;
        return this;
    }
}
URLHandler.__singleton = null;
exports.URLHandler = URLHandler;
//# sourceMappingURL=utils.js.map