"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const _1 = require('./');
const utils = require('egret-node-utils');
const ts = require('typescript');
const fs = require('fs-extra-promise');
const path = require('path');
let projectRoot;
function build(p, target) {
    return __awaiter(this, void 0, void 0, function* () {
        let resourceRoot = "resource";
        function crc32(p) {
            var c = require("crc32");
            var data = fs.readFileSync(path.join(resourcePath, p));
            var code = c(data);
            console.log(p, code);
            return code;
        }
        let add = (r) => {
            _1.ResourceConfig.addFile(r);
        };
        let copy = (r) => __awaiter(this, void 0, void 0, function* () {
            let from = path.resolve(projectRoot, resourceRoot, r.name);
            let to = path.resolve(projectRoot, target, r.url);
            yield fs.copyAsync(from, to);
        });
        let executeFilter = (f) => __awaiter(this, void 0, void 0, function* () {
            let config = _1.ResourceConfig.config;
            if (!config.filter) {
                throw "missing filter in config.resjs";
            }
            var ext = f.substr(f.lastIndexOf(".") + 1);
            let file = { path: f, fullname: path.join(resourceRoot, f), ext: ext };
            let env = { target: target, resourceRoot: resourceRoot };
            let result = yield config.filter(file, env, { crc32: crc32, add: add, copy: copy });
            return result;
        });
        let updateResourceConfigFileContent = (filename, matcher, data) => __awaiter(this, void 0, void 0, function* () {
            let replacedText = JSON.stringify(data, null, "\t");
            let config = _1.ResourceConfig.config;
            let content = yield fs.readFileAsync(filename, "utf-8");
            let sourceFile = ts.createSourceFile(filename, content, ts.ScriptTarget.ES6, /*setParentNodes */ true);
            content = yield delint(sourceFile, matcher, replacedText);
            ;
            yield fs.writeFileAsync(filename, content, "utf-8");
            return content;
        });
        projectRoot = p;
        let resourcePath = path.join(projectRoot, "resource");
        let option = {
            relative: true,
            ignoreHiddenFile: true
        };
        let filename = getResourceConfigFile();
        yield _1.ResourceConfig.init(filename);
        let list = yield utils.walk(resourcePath, () => true, option);
        yield Promise.all(list.map(executeFilter)).catch(e => console.log(e));
        yield convertResourceJson(_1.ResourceConfig.config);
        //todo : performance-optimize
        let content = yield updateResourceConfigFileContent(filename, "exports.resources", _1.ResourceConfig.config.resources);
        content = yield updateResourceConfigFileContent(filename, "exports.groups", _1.ResourceConfig.config.groups);
        content = yield updateResourceConfigFileContent(filename, "exports.alias", _1.ResourceConfig.config.alias);
        if (target) {
            var outputFileDir = path.resolve(process.cwd(), projectRoot, target);
            let outputFileName = path.join(outputFileDir, "config.resjs");
            yield fs.mkdirpAsync(outputFileDir);
            yield fs.writeFileAsync(outputFileName, content, "utf-8");
        }
    });
}
exports.build = build;
function getResourceConfigFile() {
    return path.resolve(process.cwd(), projectRoot, "resource/config.resjs");
}
//分析特定文件中的 exports.resource = {blablabla}，将其中右侧的内容进行替换
function delint(sourceFile, matcher, replacedText) {
    let config = _1.ResourceConfig.config;
    return new Promise((reslove, reject) => {
        function delintNode(node) {
            // ExpressionStatement  表达式
            //    |-- BinaryExpression 二元表达式
            //      |-- left  左侧
            //      |-- right  右侧
            if (node.kind == ts.SyntaxKind.ExpressionStatement) {
                if (node.expression.kind == ts.SyntaxKind.BinaryExpression) {
                    let expression = node.expression;
                    if (expression.left.getText() == matcher) {
                        let right = expression.right;
                        let positionStart = right.getStart();
                        let positionFinish = right.getWidth();
                        let fullText = sourceFile.getFullText();
                        fullText = fullText.substr(0, positionStart) + replacedText + fullText.substr(positionStart + positionFinish);
                        result = fullText;
                    }
                }
            }
            else {
                ts.forEachChild(node, delintNode);
            }
        }
        let result = "";
        let count = setInterval(() => {
            if (result) {
                clearInterval(count);
                reslove(result);
            }
        }, 100);
        delintNode(sourceFile);
    });
}
function convertResourceJson(config) {
    return __awaiter(this, void 0, void 0, function* () {
        let resourceJsonPath = path.join(projectRoot, "resource/default.res.json");
        if (!fs.existsSync(resourceJsonPath)) {
            resourceJsonPath = path.join(projectRoot, "resource/resource.json");
        }
        if (!fs.existsSync(resourceJsonPath)) {
            return;
        }
        let resourceJson = yield fs.readJSONAsync(resourceJsonPath);
        // let resourceJson: original.Info = await fs.readJSONAsync(resourceJsonPath);
        for (let r of resourceJson.resources) {
            config.alias[r.name] = r.url;
            let file = _1.ResourceConfig.getFile(r.url);
            for (var resource_custom_key in r) {
                if (resource_custom_key == "url" || resource_custom_key == "type" || resource_custom_key == "name") {
                    continue;
                }
                else if (resource_custom_key == "subkeys") {
                    var subkeysArr = r.subkeys.split(",");
                    for (let subkey of subkeysArr) {
                        // if (!obj.alias[subkeysArr[i]]) {
                        config.alias[subkey] = r.url + "#" + subkey;
                    }
                }
                else {
                    if (typeof file != "string") {
                        file[resource_custom_key] = r[resource_custom_key];
                    }
                    else {
                        console.warn(`missing properties ${resource_custom_key} in ${file}`);
                    }
                }
            }
        }
        for (let group of resourceJson.groups) {
            config.groups[group.name] = group.keys.split(",");
        }
    });
}
//# sourceMappingURL=build.js.map