"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const path = require('path');
const utils = require('egret-node-utils');
function parseFromPreviousVersion(lastVersionData) {
    let data = {
        resources: {},
        groups: {},
        alias: {}
    };
    ResourceConfig.data = data.resources;
    for (let resource of lastVersionData.resources) {
        let url = resource.url;
        ResourceConfig.addFile(url, resource.type);
        data.alias[resource.name] = url;
    }
    for (let group of lastVersionData.groups) {
        data.groups[group.name] = group.keys;
    }
}
exports.parseFromPreviousVersion = parseFromPreviousVersion;
var ResourceNodeType;
(function (ResourceNodeType) {
    ResourceNodeType[ResourceNodeType["FILE"] = 0] = "FILE";
    ResourceNodeType[ResourceNodeType["DICTIONARY"] = 1] = "DICTIONARY";
})(ResourceNodeType || (ResourceNodeType = {}));
function getResourceInfo(url) {
    return ResourceConfig.getFile(url);
}
exports.getResourceInfo = getResourceInfo;
function print() {
    console.log(exports.data);
}
exports.print = print;
var ResourceConfig;
(function (ResourceConfig) {
    ResourceConfig.data = {};
    function addFile(filename, type) {
        if (!type)
            type = "";
        filename = normalize(filename);
        let basefilename = basename(filename);
        let folder = dirname(filename);
        if (!exists(folder)) {
            mkdir(folder);
        }
        let d = reslove(folder);
        d[basefilename] = { url: filename, type: type };
    }
    ResourceConfig.addFile = addFile;
    function getFile(filename) {
        return reslove(filename);
    }
    ResourceConfig.getFile = getFile;
    function basename(filename) {
        return filename.substr(filename.lastIndexOf("/") + 1);
    }
    function normalize(filename) {
        return filename.split("/").filter(d => !!d).join("/");
    }
    function dirname(path) {
        return path.substr(0, path.lastIndexOf("/"));
    }
    function reslove(dirpath) {
        dirpath = normalize(dirpath);
        let list = dirpath.split("/");
        let current = ResourceConfig.data;
        for (let f of list) {
            current = current[f];
        }
        return current;
    }
    function mkdir(dirpath) {
        dirpath = normalize(dirpath);
        let list = dirpath.split("/");
        let current = ResourceConfig.data;
        for (let f of list) {
            if (!current[f]) {
                current[f] = {};
            }
            current = current[f];
        }
    }
    ResourceConfig.mkdir = mkdir;
    function exists(dirpath) {
        dirpath = normalize(dirpath);
        let list = dirpath.split("/");
        let current = ResourceConfig.data;
        for (let f of list) {
            if (!current[f]) {
                return false;
            }
            current = current[f];
        }
        return true;
    }
    ResourceConfig.exists = exists;
})(ResourceConfig = exports.ResourceConfig || (exports.ResourceConfig = {}));
function run(projectRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        let resourcePath = path.join(projectRoot, "resource");
        let filter = (path, stats) => {
            return true;
        };
        let option = {
            relative: true,
            ignoreHiddenFile: true
        };
        let list = yield utils.walk(resourcePath, filter, option);
        let obj = {
            groups: {},
            alias: {},
            resources: {}
        };
        ResourceConfig.data = obj.resources;
        for (let filename of list) {
            ResourceConfig.addFile(filename, "image");
        }
    });
}
exports.run = run;
//# sourceMappingURL=resource.js.map